@@ -128,9 +128,9 @@ sub configure_inc {
 }
 
 sub write_pm_test {
-    my($self, $module, $base, $sub) = @_;
+    my($self, $module, $sub, @base) = @_;
 
-    my $dir = catfile $self->{vars}->{t_dir}, $base;
+    my $dir = catfile $self->{vars}->{t_dir}, @base;
     my $t = catfile $dir, "$sub.t";
     return if -e $t;
 
@@ -180,6 +180,7 @@ sub configure_startup_pl {
         my $include_pl = catfile $self->{vars}->{t_conf}, 'modperl_inc.pl';
         my $fh = $self->genfile($include_pl);
         for (reverse @$inc) {
+            next unless $_;
             print $fh "use lib '$_';\n";
         }
         my $fixup = Apache::TestConfig->modperl_2_inc_fixup();
@@ -500,9 +501,11 @@ sub configure_pm_tests {
 
         $self->run_apache_test_configure($file, $module, $status);
 
-        my($base, $sub) =
+        my @base =
             map { s/^test//i; $_ } split '::', $module;
 
+        my $sub = pop @base;
+
         my $hook = ($subdir eq 'Hooks' ? $hooks{$sub} : '')
             || $hooks{$subdir} || $subdir;
 
@@ -543,7 +546,7 @@ sub configure_pm_tests {
             $self->postamble($self->$container($module), \@args) if @args;
         }
 
-        $self->write_pm_test($module, lc $base, lc $sub);
+        $self->write_pm_test($module, lc $sub, map { lc } @base);
     }
 }
 
